"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var async_1 = require("@serenity-js/core/lib/recording/async");
var BrowseTheWeb = (function () {
    function BrowseTheWeb(browser) {
        this.browser = browser;
    }
    /**
     *
     * Instantiates the Ability to BrowseTheWeb, allowing the Actor to interact with a Web UI
     *
     * @param browser
     * @return {BrowseTheWeb}
     */
    BrowseTheWeb.using = function (browser) {
        return new BrowseTheWeb(browser);
    };
    /**
     * Used to access the Actor's ability to BrowseTheWeb from within the Interaction classes, such as Click or Enter
     *
     * @param actor
     * @return {BrowseTheWeb}
     */
    BrowseTheWeb.as = function (actor) {
        return actor.abilityTo(BrowseTheWeb);
    };
    BrowseTheWeb.prototype.locate = function (target) {
        return target.resolveUsing(this.browser.element);
    };
    BrowseTheWeb.prototype.locateAll = function (target) {
        return target.resolveAllUsing(this.browser.element);
    };
    BrowseTheWeb.prototype.takeScreenshot = function () {
        var _this = this;
        return async_1.defer(function () { return _this.browser.takeScreenshot(); });
    };
    BrowseTheWeb.prototype.get = function (destination, timeout) {
        return this.browser.get(destination, timeout);
    };
    BrowseTheWeb.prototype.getTitle = function () {
        return this.browser.getTitle();
    };
    BrowseTheWeb.prototype.actions = function () {
        return this.browser.actions();
    };
    BrowseTheWeb.prototype.manage = function () {
        return this.browser.driver.manage();
    };
    BrowseTheWeb.prototype.switchToParentWindow = function () {
        if (!this.parentWindow) {
            throw new Error('This window does not have a parent');
        }
        return this.browser.switchTo().window(this.parentWindow);
    };
    BrowseTheWeb.prototype.switchToWindow = function (handle) {
        var _this = this;
        return this.browser.getWindowHandle().then(function (currentWindow) {
            _this.parentWindow = currentWindow;
            return _this.browser.getAllWindowHandles().then(function (handles) {
                return _this.browser.switchTo().window(handle(handles));
            });
        });
    };
    BrowseTheWeb.prototype.sleep = function (millis) {
        var _this = this;
        return async_1.defer(function () { return _this.browser.sleep(millis); });
    };
    BrowseTheWeb.prototype.wait = function (condition, timeout, message) {
        return this.browser.wait(condition, timeout, message);
    };
    BrowseTheWeb.prototype.enableAngularSynchronisation = function (enable) {
        return this.browser.waitForAngularEnabled(enable);
    };
    BrowseTheWeb.prototype.executeScript = function (script, target) {
        return this.browser.executeScript(script, target.resolveUsing(this.browser.element));
    };
    BrowseTheWeb.prototype.executeAsyncScript = function (script, target) {
        var args = [];
        for (var _i = 2; _i < arguments.length; _i++) {
            args[_i - 2] = arguments[_i];
        }
        return (_a = this.browser).executeAsyncScript.apply(_a, [script, target.resolveUsing(this.browser.element)].concat(args));
        var _a;
    };
    return BrowseTheWeb;
}());
exports.BrowseTheWeb = BrowseTheWeb;
//# sourceMappingURL=browse_the_web.js.map